@@ -110,6 +110,9 @@ METRIC.G <- function(image.DN, WeatherStation=WeatherStation, Rn,
 #' @param DEM              Digital Elevation Model of the study area. Not needed
 #' if plain = TRUE
 #' @param aoi              SpatialPolygon object with limits of Area of interest
+#' @param G.method         method used for the G estimation. Currently implemeted are 
+#'                         "Tasumi" for Tasumi,2003 or "Bastiaanssen" for Bastiaanssen, 2000
+
 #' @param alb.coeff        coefficient to transform narrow to broad band albedo.
 #' See Details.
 #' @param LST.method       Method for land surface temperature estimation. "SC" 
@@ -147,6 +150,7 @@ METRIC.G <- function(image.DN, WeatherStation=WeatherStation, Rn,
 #' @family METRIC model functions
 #' @references 
 #' R. G. Allen, M. Tasumi, and R. Trezza, "Satellite-based energy balance for mapping evapotranspiration with internalized calibration (METRIC) - Model" Journal of Irrigation and Drainage Engineering, vol. 133, p. 380, 2007
+#' González, Arturo & Hay, Christopher & Kjaersgaard, Jeppe & Neale, Christopher. (2015). Use of Remote Sensing to Generate Crop Coefficient and Estimate Actual Crop Evapotranspiration. 10.13031/aim.20152190105. 
 #' @examples 
 #' ### Data preparation
 #' library(water)
@@ -180,7 +184,7 @@ METRIC.G <- function(image.DN, WeatherStation=WeatherStation, Rn,
 #' }
 #' @export
 METRIC.EB <- function(image.DN, image.SR, WeatherStation, MTL, sat = "auto",
-                      thermalband, plain=TRUE, DEM, aoi,
+                      thermalband, plain=TRUE, DEM, aoi, G.method = "Tasumi",
                       alb.coeff = "Tasumi", LST.method = "SC",
                       LAI.method = "metric2010", L = 0.1,
                       Zom.method = "short.crops", anchors.method = "CITRA-MCB",
@@ -226,11 +230,11 @@ METRIC.EB <- function(image.DN, image.SR, WeatherStation, MTL, sat = "auto",
   Rl.inc <- incLWradiation(WeatherStation,DEM = surface.model$DEM, 
                            solar.angles = solar.angles.r, Ts= Ts)
   Rn <- netRadiation(LAI, albedo, Rs.inc, Rl.inc, Rl.out)
-  Rn[Rn < 0]  <-  0
+  # Rn[Rn < 0]  <-  0 # see H
   #setTxtProgressBar(pb, 40)
   G <- soilHeatFlux(image = image.SR, Ts=Ts,albedo=albedo, 
-                    Rn=Rn, LAI=LAI)
-  G[G < 0]  <-  0
+                    Rn=Rn, LAI=LAI, method = G.method)
+  # G[G < 0]  <-  0 # see H
   if(Zom.method == "short.crops"){
     Z.om <- momentumRoughnessLength(LAI=LAI, mountainous = !plain, 
                                     method = Zom.method, 
@@ -267,14 +271,27 @@ METRIC.EB <- function(image.DN, image.SR, WeatherStation, MTL, sat = "auto",
     print(anchors)
   }
   #setTxtProgressBar(pb, 45)
+  if(anchors.method == "flexible"){
+     flex.cold <- anchors$flex
+     NDVIcold <- mean(as.numeric(anchors$NDVI[anchors$type == "cold"]))
+     print(paste0("mean NDVI for cold pixel: ", NDVIcold))
+     # NDVI and Kc relationship from:
+     #González, Arturo & Hay, Christopher & Kjaersgaard, Jeppe & Neale, 
+     #Christopher. (2015). Use of Remote Sensing to Generate Crop Coefficient 
+     #and Estimate Actual Crop Evapotranspiration. 10.13031/aim.20152190105. 
+     ETp.coef <-  2.11 * NDVIcold - 0.4989 
+     print(paste0("ETp.coef updated to: ", ETp.coef, " (Gonzalez et al, 2015)"))
+
+  }
   H <- calcH(anchors = anchors, Ts = Ts, Z.om = Z.om, mountainous = !plain,
              WeatherStation = WeatherStation, ETp.coef = ETp.coef,
              Z.om.ws = Z.om.ws, DEM = DEM, Rn = Rn, G = G, verbose = verbose)
   par(mfrow=c(1,1))
   #setTxtProgressBar(pb, 99)
   H <-  H$H
+  # H[H < 0]  <-  0  not a good solution...! not for any of the components
   LE <- Rn - G - H
-  LE[LE < 0]  <-  0
+  LE[LE < 0]  <-  0   # see H
   EB <- stack(Rn, G, H, LE, Ts)
   EB <- saveLoadClean(imagestack = EB,
                 stack.names = c("NetRadiation", "SoilHeat", "SensibleHeat", 
