@@ -9,9 +9,11 @@ aoi <- createAoi(topleft = c(272955, 6085705),
 ## ------------------------------------------------------------------------
 csvfile <- system.file("extdata", "apples.csv", package="water")
 MTLfile <- system.file("extdata", "L7.MTL.txt", package="water")
-WeatherStation <- read.WSdata(WSdata = csvfile, date.format = "%d/%m/%Y",
-                  lat=-35.42222, long= -71.38639, elev=201, height= 2.2,
-                  MTL = MTLfile)
+WeatherStation <- read.WSdata(WSdata = csvfile, date.format = "%d/%m/%Y", 
+                              lat=-35.42222, long= -71.38639, elev=201, height= 2.2,
+                              columns=c("date" = 1, "time" = 2, "radiation" = 3,
+                              "wind" = 4, "RH" = 6, "temp" = 7, "rain" = 8), 
+                              MTL = MTLfile)
 
 ## ---- fig.width = 5------------------------------------------------------
 print(WeatherStation)
@@ -29,14 +31,14 @@ Energy.Balance <- METRIC.EB(image.DN = image.DN, plain=TRUE,
                             sat="L7", thermalband=image.DN$thermal.low)
 
 ## ---- fig.width = 5------------------------------------------------------
-plot(Energy.Balance)
+plot(Energy.Balance$EB)
 
 ## ------------------------------------------------------------------------
 ET_WS <- dailyET(WeatherStation = WeatherStation, MTL = MTLfile)
 
 ## ---- fig.width = 5, warning=FALSE---------------------------------------
-ET.24 <- ET24h(Rn=Energy.Balance$NetRadiation, G=Energy.Balance$SoilHeat, 
-               H=Energy.Balance$SensibleHeat, 
-               Ts=Energy.Balance$surfaceTemperature, 
+ET.24 <- ET24h(Rn=Energy.Balance$EB$NetRadiation, G=Energy.Balance$EB$SoilHeat, 
+               H=Energy.Balance$EB$SensibleHeat, 
+               Ts=Energy.Balance$EB$surfaceTemperature, 
                WeatherStation = WeatherStation, ETr.daily=ET_WS)
 
